@@ -17,10 +17,8 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-import os
 import gtk
 import pango
-import urllib
 import threading
 import hildon
 
