@@ -109,6 +109,19 @@ class Store(object):
             self.db.execute('INSERT INTO %s (%s) VALUES (%s)' % (table,
                 ', '.join(slots), ', '.join('?'*len(slots))), values)
 
+    def delete(self, class_, **kwargs):
+        with self.lock:
+            self._register(class_)
+            table, slots = self._schema(class_)
+            sql = 'DELETE FROM %s' % (table,)
+            if kwargs:
+                sql += ' WHERE %s' % (' AND '.join('%s=?' % k for k in kwargs))
+            try:
+                self.db.execute(sql, kwargs.values())
+                return True
+            except Exception, e:
+                return False
+
     def remove(self, o):
         if hasattr(o, '__iter__'):
             for child in o:
@@ -136,14 +149,16 @@ class Store(object):
             try:
                 cur = self.db.execute(sql, kwargs.values())
             except Exception, e:
-                print sql
                 raise
             def apply(row):
                 o = class_.__new__(class_)
                 for attr, value in zip(slots, row):
-                    self._set(o, attr, value)
+                    try:
+                        self._set(o, attr, value)
+                    except ValueError, ve:
+                        return None
                 return o
-            return [apply(row) for row in cur]
+            return filter(lambda x: x is not None, [apply(row) for row in cur])
 
     def get(self, class_, **kwargs):
         result = self.load(class_, **kwargs)
